@@ -464,9 +464,17 @@ WikiData::WikiData(wxString* dataDir, wxString* inFileName)
 }
 
 WikiData::WikiData(wxString* dataDir) {
+	FILE*      fp;
 	time_t     now;
 	char       buf[MAX_BUF_SIZE];
-	wxCSConv    conv(wxT(CODE_SET_SYSTEM));
+	char       fname[MAX_BUF_SIZE];
+	char       templateBuf[MAX_BUF_SIZE];
+	char*      inbufPtr;
+	int        inbufSize;
+	char       outbuf[MAX_BUF_SIZE];
+	char*      outbufPtr;
+	int        outbufSize;
+	wxCSConv   conv(wxT(CODE_SET_SYSTEM));
 
 	dataDirName = new wxString(dataDir->mb_str(), conv);
 
@@ -482,11 +490,36 @@ WikiData::WikiData(wxString* dataDir) {
 	memset(buf, 0, sizeof(buf));
 	strftime(buf, sizeof(buf), DATE_TAG "%Y/%m/%d %H:%M:%S",localtime(&now));
 	date    = new wxString(buf, conv);
+
+	/* try to open template file */
+	snprintf(fname, sizeof(fname), "%s/%s", (const char*)(dataDir->mb_str()), NEW_DATA_TEMPLATE);
+	fp = fopen(fname, "r");
+	if(fp == NULL){
+		memset(buf, 0, sizeof(buf));
+		strftime(buf, sizeof(buf), NEW_DATA,localtime(&now));
+	}
+	else {
+		memset(buf, 0, sizeof(buf));
+		memset(templateBuf, 0, sizeof(templateBuf));
+		memset(outbuf, 0, sizeof(outbuf));
+		fread(templateBuf, sizeof(templateBuf), 1, fp);
 	
-	memset(buf, 0, sizeof(buf));
-	strftime(buf, sizeof(buf), NEW_DATA,localtime(&now));
+		iconv_t codeSet = iconv_open(CODE_SET_SYSTEM, CODE_SET_EUC_JP);
+		if(codeSet == (iconv_t)-1) {
+			MN_FATAL_ERROR(wxT("failed iconv_open"));
+		}
+		inbufPtr = templateBuf;
+	    outbufPtr = outbuf;
+		inbufSize = strlen(templateBuf);
+		outbufSize = sizeof(outbuf);
+		iconv(codeSet, (ICONV_CONST char**)&inbufPtr, (size_t*)&inbufSize, &outbufPtr, (size_t*)&outbufSize);
+		
+		strftime(buf, sizeof(buf), outbuf,localtime(&now));
+
+	}
 	text    = new wxString(buf, conv);
 
+	if(fp) fclose(fp);
 }
 
 WikiData::~WikiData()
@@ -679,6 +712,9 @@ void WikiData::save()
 	outbufSize = sizeof(outbuf);
 	memset(outbuf, 0, outbufSize);
 	iconv(codeSet, (ICONV_CONST char**)&inbufPtr, (size_t*)&inbufSize, &outbufPtr, (size_t*)&outbufSize);
+	if(inbufSize != 0) { // iconv error
+		wxMessageBox(wxT("Fail to save, because this memo include KISHU-IZON-MOJI.\nPlease remove KISHU-IZON-MOJI, and try again"), wxT("Fail to save"), wxOK|wxICON_WARNING);
+	}
 	fwrite(outbuf, sizeof(outbuf)-outbufSize, 1, fp);
 	fclose(fp);
 	iconv_close(codeSet);
